local MAJOR, MINOR = "LibPetBreedInfo-1.0", 40
local lib, oldminor = LibStub:NewLibrary(MAJOR, MINOR)

if not lib then return end
lib.breedData = {}
--
-- GLOBALS:
--

local _G = _G
local hooksecurefunc, tinsert, pairs, wipe = _G.hooksecurefunc, _G.table.insert, _G.pairs, _G.wipe
local ipairs = _G.ipairs
local C_PetJournal,C_PetBattles = _G.C_PetJournal, _G.C_PetBattles
local _
local EMPTY_PET = "0x0000000000000000"
local epsilion = .005
local STATE_Mod_SpeedPrecent = 25
local STATE_MaxHealthBonus = 2
local STATE_Mod_MaxHealthPrercent = 99
local HEALTH,POWER,SPEED = 1,2,3
local BASE_HEALTH = 100
local HEALTH_PER_STAMINA = 5
local FALLBACK_BREEDS = {3,4,5,6,7,8,9,10,11,12}
local WILD_PET_HEALTH_MULTIPLIER = 1.2
local MAX_PETS_PER_TEAM = 3
--
-- Non Lib helper functions
--
local function round(num, idp)
  local mult = 10^(idp or 0)
  return math.floor(num * mult + 0.5) / mult
end

local function clamp(num,minVal,maxVal)
	return math.min(math.max(num,minVal),maxVal)
end

local function inverseStats(num)
	return num ~= 0 and 100/(num+100) or 1
end


--Gets the breed index for the given pet
--Returns arg1: petIndex that can be used by GetBreedName to return the breeds name. arg2: a confidence indicator, lower numbers are better. A good cutoff for high confidence is .15
--Returns nil if the species cannot battle or does not have a base stats profile or if the petID is not valid
function lib:GetBreedByPetID(petID)
	if petID then
		local speciesID, _, level, _, _, _,_ ,_, _, _, _, _, _, _, canBattle = C_PetJournal.GetPetInfoByPetID(petID)
		if not canBattle then return end
		local _, maxHealth, power, speed, rarity = C_PetJournal.GetPetStats(petID)
			return self:GetBreedByStats(speciesID,level,rarity,maxHealth,power,speed)
	end
end

--Gets the breed index for the given hypothetical pet
--Returns arg1: petIndex that can be used by GetBreedName to return the breeds name. arg2: a confidence indicator, lower numbers are better. A good cutoff for high confidence is .15
--Returns nil if the species cannot battle or does not have a base stats profile or if level, health power and speed are not numbers and rarity is not between 1 and 4
function lib:GetBreedByStats(speciesID,level,rarity,health,power,speed)
	if not self.breedData.speciesToBaseStatProfile[speciesID] or not self.breedData.qualityMultiplier[rarity] or  
		type(level) ~= "number" or type(health) ~= "number" or type(power) ~= "number" or type(speed) ~= "number" then 
			return 
	end
	local canBattle      = select(8,C_PetJournal.GetPetInfoBySpeciesID(speciesID))
	if not canBattle then return end
	local baseStats         = self.breedData.speciesToBaseStatProfile[speciesID]
	local qualityMultiplier = self.breedData.qualityMultiplier[rarity]

	health = clamp(round(( ((health-BASE_HEALTH)/HEALTH_PER_STAMINA) / qualityMultiplier) - level * baseStats[HEALTH],1) / level,0,2)
	power  = clamp(round((									  power  / qualityMultiplier) - level * baseStats[POWER] ,1) / level,0,2)
	speed  = clamp(round((                                    speed  / qualityMultiplier) - level * baseStats[SPEED] ,1) / level,0,2)
	local breeds = self:GetAvailableBreeds(speciesID)
	breeds = --[[breeds and breeds or]] FALLBACK_BREEDS
	local leastDiff = 100
	local leastDiff2 = 100
	local breedID = 0
	for i=1,#breeds do
		local breedIndex = breeds[i]
		local breedData = self.breedData.breeds[breedIndex]
		local diff = round(math.abs(health - breedData[HEALTH]) + math.abs(power - breedData[POWER]) + math.abs(speed - breedData[SPEED]),2) + epsilion
			if diff < leastDiff then
			leastDiff2 = leastDiff
			leastDiff  = diff
			breedID    = breedIndex
		elseif diff < leastDiff2 then
			leastDiff2 = diff
		end
		end
	return breedID, round(leastDiff2 / leastDiff ,2)
end



--Gets the breed index for the given pet
--!!!Results are not valid if computed while a round play back is happening!!!
--Returns arg1: petIndex that can be used by GetBreedName to return the breeds name. arg2: a confidence indicator, lower numbers are better. A good cutoff for high confidence is .15
--Returns nil if the species cannot battle or does not have a base stats profile, or an invalid petOwner/petID is used, or if the player is not in a pet battle

--/run print(C_PetBattles.GetName(1,1),LibStub("LibPetBreedInfo-1.0"):GetBreedByPetBattleSlot(1,1))
function lib:GetBreedByPetBattleSlot(petOwner,id)
	if not C_PetBattles.IsInBattle() then return end
	if petOwner ~= LE_BATTLE_PET_ALLY and petOwner ~= LE_BATTLE_PET_ENEMY then return end
	if id <= 0 or id > MAX_PETS_PER_TEAM and id <= C_PetBattles.GetNumPets(petOwner) then return end
	local speedMultiplier  = C_PetBattles.GetStateValue(petOwner,id,STATE_Mod_SpeedPrecent)
	local healthMultiplier = C_PetBattles.GetStateValue(petOwner,id,STATE_Mod_MaxHealthPrercent)
	local healthModifier   = C_PetBattles.GetStateValue(petOwner,id,STATE_MaxHealthBonus)
	if not speedMultiplier or not healthMultiplier or not healthModifier then return end
	speedMultiplier  = inverseStats(speedMultiplier)
	healthMultiplier = inverseStats(healthMultiplier)

	if C_PetBattles.IsWildBattle() and petOwner == LE_BATTLE_PET_ENEMY then
		healthMultiplier = healthMultiplier * WILD_PET_HEALTH_MULTIPLIER
	end
	local speciesID = C_PetBattles.GetPetSpeciesID(petOwner,id)
	local speed     = round(C_PetBattles.GetSpeed(petOwner,id) * speedMultiplier)
	local power     = C_PetBattles.GetPower(petOwner,id)
	local health    = (C_PetBattles.GetMaxHealth(petOwner,id) * healthMultiplier) - healthModifier
	local rarity    = C_PetBattles.GetBreedQuality(petOwner,id)
	local level     = C_PetBattles.GetLevel(petOwner,id)
	return self:GetBreedByStats(speciesID,level,rarity,health,power,speed)
end


--Gets the predicted stats for a species at a given level
--returns health,power,speed
--returns nil if the pet does not have a base stats profile, or if an invalid... breedID, rarity, or non numeric level is given.
--/run print(LibStub("LibPetBreedInfo-1.0"):GetPetPredictedStats(1229,5,4,1))
function lib:GetPetPredictedStats(speciesID, breedID, rarity, level)
	if not self.breedData.breeds[breedID] or not self.breedData.speciesToBaseStatProfile[speciesID] or type(level) ~= "number" or not self.breedData.qualityMultiplier[rarity] then return end
	local baseStats      = self.breedData.speciesToBaseStatProfile[speciesID]
	local multiplier     = self.breedData.qualityMultiplier[rarity]
	local breedStats     = self.breedData.breeds[breedID]
	local health = (round((baseStats[HEALTH] + breedStats[HEALTH]) * multiplier * level * HEALTH_PER_STAMINA) + BASE_HEALTH)
	local power  = round((baseStats[POWER]  + breedStats[POWER])  * multiplier * level) 
	local speed  = round((baseStats[SPEED]  + breedStats[SPEED])  * multiplier * level)
	return health, power , speed
end

--Gets a table containing the possible BreedID's for a given species
--Returns nil if no data is present for the given speciesID
--[[
function lib:GetAvailableBreeds(speciesID)
end]]

--Gets an iterator for all of the possible breed names
function lib:IterateBreedNames()
	return pairs(self.breedData.breedNames)
end

--Gets the string representation of a BreedID
--Returns nil for invalid breedID's
function lib:GetBreedName(breedID)
	return self.breedData.breedNames[breedID]
end


--Gets a table of possible breedId's for a given species
--BreedIDs are from 1-10
--Returns nil for invalid speciesID's
function lib:GetAvailableBreeds(speciesID)
	return self.breedData.speciesToAvailableBreeds[speciesID]
end

--/lb code LibStub("LibPetBreedInfo-1.0"):GetSpeciesWithoutProfiles()
--Gets a table of speciesIDs which are present in game but do not have a base stats profile
--This is a dev function to make updating this library easier
--Returns a table
--[[
function lib:GetSpeciesWithoutProfiles()
	local missingPets = {}
	for i=1,2000 do --2000 to catch new pet IDs
		name = C_PetJournal.GetPetInfoBySpeciesID(i)
		if name and not self.breedData.speciesToBaseStatProfile[i] then
			tinsert(missingPets,i)
		end
	end
	return missingPets
end]]

--/run LibStub("LibPetBreedInfo-1.0"):FindMissingSpeciesBreeds()
--[[function lib:FindMissingSpeciesBreeds()
	local lpj = LibStub("LibPetJournal-2.0")
	local availableBreeds = self.breedData.speciesToAvailableBreeds
	for _,v in lpj:IterateSpeciesIDs() do
		if not availableBreeds[v] then
			print(v,C_PetJournal.GetPetInfoBySpeciesID(v))
		end
	end
end]]

--/run LibStub("LibPetBreedInfo-1.0"):ExtractData()
--[[function lib:ExtractData()
	BPBID.InitializeArrays()
	local speciesToBaseStatProfile= self.breedData.speciesToBaseStatProfile
	for k,v in pairs(BPBID.BasePetStats) do
		if not speciesToBaseStatProfile[k] then 
			print(k)
		end
	end
end]]




lib.breedData.breeds = {
	[3]={.5,.5,.5}, --1
	[4]={0,2,0}, --2
	[5]={0,0,2}, --3
	[6]={2,0,0}, --4 
	[7]={.9,.9,0},--5
	[8]={0,.9,.9},--6
	[9]={.9,0,.9},--7
	[10]={.4,.9,.4},--8
	[11]={.4,.4,.9},--9
	[12]={.9,.4,.4}--10
}

lib.breedData.breedNames = {
	[3]="B/B", --1
	[4]="P/P", --2
	[5]="S/S", --3
	[6]="H/H", --4 
	[7]="H/P",--5
	[8]="P/S",--6
	[9]="H/S",--7
	[10]="P/B",--8
	[11]="S/B",--9
	[12]="H/B"--10
}

lib.breedData.qualityMultiplier = {1,1.1,1.2,1.3,1.4}


lib.breedData.speciesToBaseStatProfile = {
    [1] = false,
	[2] = {510.5, 8, 9.5},
	[3] = false,
	[4] = false,
	[5] = false,
	[6] = false,
	[7] = false,
	[8] = false,
	[9] = false,
	[10] = false,
	[11] = false,
	[12] = false,
	[13] = false,
	[14] = false,
	[15] = false,
	[16] = false,
	[17] = false,
	[18] = false,
	[19] = false,
	[20] = false,
	[21] = false,
	[22] = false,
	[23] = false,
	[24] = false,
	[25] = false,
	[26] = false,
	[27] = false,
	[28] = false,
	[29] = false,
	[30] = false,
	[31] = false,
	[32] = false,
	[33] = false,
	[34] = false,
	[35] = false,
	[36] = false,
	[37] = false,
	[38] = false,
	[39] = {8.5, 7.5, 8},
	[40] = {7, 8.5, 8.5},
	[41] = {7, 8.5, 8.5},
	[42] = {6.5, 9, 8.5},
	[43] = {7, 9, 8},
	[44] = {7, 8.5, 8.5},
	[45] = {7, 8.5, 8.5},
	[46] = {7.5, 7.5, 9},
	[47] = {8, 7.5, 8.5},
	[48] = false,
	[49] = {9, 7, 8},
	[50] = {9, 8, 7},
	[51] = {8.5, 8, 7.5},
	[52] = {8, 8, 8},
	[53] = false,
	[54] = false,
	[55] = {8.5, 7, 8.5},
	[56] = {8.5, 9, 6.5},
	[57] = {8.5, 7.5, 8},
	[58] = {7, 9, 8},
	[59] = {8.5, 8, 7.5},
	[60] = false,
	[61] = false,
	[62] = false,
	[63] = false,
	[64] = {8.5, 7.5, 8},
	[65] = {8.5, 7.5, 8},
	[66] = false,
	[67] = {8, 8, 8},
	[68] = {8, 8, 8},
	[69] = {7.5, 7.5, 9},
	[70] = {8, 7.5, 8.5},
	[71] = {8, 8, 8},
	[72] = {8, 7, 9},
	[73] = {8, 8, 8},
	[74] = {7.5, 7.5, 9},
	[75] = {7.5, 8.5, 8},
	[76] = false,
	[77] = {8, 8, 8},
	[78] = {7.5, 8.5, 8},
	[79] = false,
	[80] = false,
	[81] = false,
	[82] = false,
	[83] = {8.5, 7.5, 8},
	[84] = {8, 8, 8},
	[85] = {8.5, 7.5, 8},
	[86] = {8.5, 7.5, 8},
	[87] = {8, 8.5, 7.5},
	[88] = false,
	[89] = {8, 8, 8},
	[90] = {7, 8.5, 8.5},
	[91] = false,
	[92] = {8, 8, 8},
	[93] = {6.5, 9, 8.5},
	[94] = {7, 7, 10},
	[95] = {8, 8, 8},
	[96] = false,
	[97] = false,
	[98] = false,
	[99] = false,
	[100] = false,
	[101] = false,
	[102] = false,
	[103] = false,
	[104] = false,
	[105] = false,
	[106] = {8.5, 7.5, 8},
	[107] = {8, 8, 8},
	[108] = false,
	[109] = false,
	[110] = false,
	[111] = {8, 8, 8},
	[112] = false,
	[113] = false,
	[114] = {8.5, 8.5, 7},
	[115] = {8, 8, 8},
	[116] = {8, 8, 8},
	[117] = {8, 8, 8},
	[118] = {8, 8, 8},
	[119] = {8, 8, 8},
	[120] = {8, 8, 8},
	[121] = {8, 8, 8},
	[122] = {8, 8, 8},
	[123] = false,
	[124] = {8, 8, 8},
	[125] = {8, 8, 8},
	[126] = {8, 8, 8},
	[127] = {8, 7.5, 8.5},
	[128] = {8, 8, 8},
	[129] = false,
	[130] = {8, 8, 8},
	[131] = {8, 7.5, 8.5},
	[132] = {9, 8, 7},
	[133] = false,
	[134] = false,
	[135] = false,
	[136] = {8, 8, 8},
	[137] = {8, 7, 9},
	[138] = {8.5, 7.5, 8},
	[139] = {7.5, 8.5, 8},
	[140] = {8, 8.5, 7.5},
	[141] = {7.5, 7.5, 9},
	[142] = {8, 8.5, 7.5},
	[143] = {7.5, 8.5, 8},
	[144] = {7.5, 7.5, 9},
	[145] = {8.5, 7.5, 8},
	[146] = {7.5, 8, 8.5},
	[147] = false,
	[148] = false,
	[149] = {7.5, 7, 9.5},
	[150] = false,
	[151] = false,
	[152] = false,
	[153] = {8, 8, 8},
	[154] = false,
	[155] = {8, 8, 8},
	[156] = {8, 8, 8},
	[157] = {8, 8, 8},
	[158] = {8, 8, 8},
	[159] = {8, 8, 8},
	[160] = {8, 8, 8},
	[161] = false,
	[162] = {8, 8.5, 7.5},
	[163] = {8, 8.5, 7.5},
	[164] = {8, 8.5, 7.5},
	[165] = {8.5, 7.5, 8},
	[166] = {8.5, 8.5, 7},
	[167] = {9, 7.5, 7.5},
	[168] = {8.5, 7.5, 8},
	[169] = {8, 8, 8},
	[170] = {8, 8, 8},
	[171] = {8, 8, 8},
	[172] = {7.5, 8.5, 8},
	[173] = {8, 8.5, 7.5},
	[174] = {8, 8.5, 7.5},
	[175] = {7.5, 8.5, 8},
	[176] = false,
	[177] = false,
	[178] = false,
	[179] = {8.5, 8, 7.5},
	[180] = {8.5, 8, 7.5},
	[181] = false,
	[182] = false,
	[183] = {8, 8, 8},
	[184] = false,
	[185] = false,
	[186] = {7.5, 8.5, 8},
	[187] = {8.5, 8.5, 7},
	[188] = {8.5, 8.5, 7},
	[189] = {8, 8, 8},
	[190] = {8.5, 8.5, 7},
	[191] = {8.5, 7.5, 8},
	[192] = {8, 8, 8},
	[193] = {8, 8.5, 7.5},
	[194] = {8, 8, 8},
	[195] = {7.5, 7.5, 9},
	[196] = {8.5, 8, 7.5},
	[197] = {7.5, 8, 8.5},
	[198] = {8, 8, 8},
	[199] = {8, 8, 8},
	[200] = {8, 7, 9},
	[201] = {8, 8, 8},
	[202] = {8, 8, 8},
	[203] = {8, 7, 9},
	[204] = {8, 8, 8},
	[205] = {8, 8, 8},
	[206] = {8.5, 8.5, 7},
	[207] = {8, 8, 8},
	[208] = false,
	[209] = {8, 8, 8},
	[210] = {8, 8, 8},
	[211] = {8.5, 8, 7.5},
	[212] = {8, 8, 8},
	[213] = {8, 8, 8},
	[214] = {8, 8, 8},
	[215] = {8.5, 7.5, 8},
	[216] = {8, 8, 8},
	[217] = {8, 8, 8},
	[218] = {8.5, 7.5, 8},
	[219] = false,
	[220] = {8, 8, 8},
	[221] = false,
	[222] = false,
	[223] = false,
	[224] = {7, 8.5, 8.5},
	[225] = {8, 8, 8},
	[226] = {8, 8, 8},
	[227] = {8, 8, 8},
	[228] = {8, 8, 8},
	[229] = {8, 8, 8},
	[230] = false,
	[231] = {8.5, 8, 7.5},
	[232] = {7, 8.5, 8.5},
	[233] = {7, 8.5, 8.5},
	[234] = {7, 8.5, 8.5},
	[235] = {7, 8.5, 8.5},
	[236] = {7.5, 8.5, 8},
	[237] = {7, 8.5, 8.5},
	[238] = {7, 8.5, 8.5},
	[239] = {8, 8, 8},
	[240] = {8.5, 8.5, 7},
	[241] = {8, 8, 8},
	[242] = {7.5, 8.5, 8},
	[243] = {9, 9, 6},
	[244] = {8.5, 9, 6.5},
	[245] = {8, 8, 8},
	[246] = {8, 8, 8},
	[247] = {8, 8, 8},
	[248] = {8, 8, 8},
	[249] = {8.5, 8.5, 7},
	[250] = {7.5, 9, 7.5},
	[251] = {8.5, 8.5, 7},
	[252] = false,
	[253] = {8, 8, 8},
	[254] = {8, 8, 8},
	[255] = {7.5, 9, 7.5},
	[256] = {8, 9, 7},
	[257] = {8, 8, 8},
	[258] = {8.5, 9, 6.5},
	[259] = {8.5, 7.5, 8},
	[260] = {8, 8.5, 7.5},
	[261] = {8.5, 7.5, 8},
	[262] = {8.5, 7.5, 8},
	[263] = false,
	[264] = {8.5, 8.5, 7},
	[265] = {9.5, 8, 6.5},
	[266] = {8.5, 8.5, 7},
	[267] = {8, 8, 8},
	[268] = {8.5, 9, 6.5},
	[269] = false,
	[270] = {8.5, 8.5, 7},
	[271] = {8, 7.5, 8.5},
	[272] = {9, 7.5, 7.5},
	[273] = false,
	[274] = false,
	[275] = false,
	[276] = false,
	[277] = {8.5, 7.5, 8},
	[278] = {8, 8, 8},
	[279] = {8, 8, 8},
	[280] = {8, 8, 8},
	[281] = {8, 8, 8},
	[282] = {8, 8, 8},
	[283] = {8, 8, 8},
	[284] = false,
	[285] = {8, 9, 7},
	[286] = {9, 8, 7},
	[287] = {8, 7.5, 8.5},
	[288] = false,
	[289] = {9.5, 8.5, 6},
	[290] = false,
	[291] = {9, 7.5, 7.5},
	[292] = {8, 8, 8},
	[293] = {8, 8, 8},
	[294] = {8, 8, 8},
	[295] = false,
	[296] = {8, 8, 8},
	[297] = {8, 9.5, 6.5},
	[298] = {8, 8, 8},
	[299] = false,
	[300] = false,
	[301] = {7, 8.5, 8.5},
	[302] = {8.5, 8.5, 7},
	[303] = {7, 8.5, 8.5},
	[304] = false,
	[305] = false,
	[306] = {7, 8.5, 8.5},
	[307] = {8, 8, 8},
	[308] = {8, 8, 8},
	[309] = {6.5, 9, 8.5},
	[310] = {8, 8, 8},
	[311] = {8.5, 8, 7.5},
	[312] = false,
	[313] = false,
	[314] = false,
	[315] = false,
	[316] = {8.5, 7.5, 8},
	[317] = {8.5, 8.5, 7},
	[318] = {7.5, 8.5, 8},
	[319] = {6.5, 9, 8.5},
	[320] = {8.5, 7.5, 8},
	[321] = {8, 8, 8},
	[322] = false,
	[323] = {8, 8, 8},
	[324] = false,
	[325] = {7.5, 9, 7.5},
	[326] = false,
	[327] = false,
	[328] = {8, 8, 8},
	[329] = {8, 8, 8},
	[330] = {8, 8, 8},
	[331] = {8, 8, 8},
	[332] = {8, 8, 8},
	[333] = {8, 8, 8},
	[334] = false,
	[335] = {9, 7.5, 7.5},
	[336] = {8, 8, 8},
	[337] = {8, 8, 8},
	[338] = {8.5, 7.5, 8},
	[339] = {8, 8, 8},
	[340] = {8, 8, 8},
	[341] = {8, 8, 8},
	[342] = {8, 8, 8},
	[343] = {7, 8.5, 8.5},
	[344] = {8.5, 8, 7.5},
	[345] = {8, 8.5, 7.5},
	[346] = {8, 8, 8},
	[347] = {8, 8.75, 7.25},
	[348] = {8.5, 8.5, 7},
	[349] = false,
	[350] = false,
	[351] = false,
	[352] = false,
	[353] = false,
	[354] = {8, 8, 8},
	[355] = false,
	[356] = false,
	[357] = false,
	[358] = false,
	[359] = false,
	[360] = false,
	[361] = false,
	[362] = false,
	[363] = false,
	[364] = false,
	[365] = false,
	[366] = false,
	[367] = false,
	[368] = false,
	[369] = false,
	[370] = false,
	[371] = false,
	[372] = false,
	[373] = false,
	[374] = {8, 8, 8},
	[375] = {8, 8, 8},
	[376] = false,
	[377] = false,
	[378] = {8, 7, 9},
	[379] = {8, 7.5, 8.5},
	[380] = {8, 8, 8},
	[381] = {8, 8, 8},
	[382] = {8, 8, 8},
	[383] = {8, 7.5, 8.5},
	[384] = {8, 8, 8},
	[385] = {8, 7.5, 8.5},
	[386] = {8, 7.5, 8.5},
	[387] = {7.5, 8, 8.5},
	[388] = {8.5, 8, 7.5},
	[389] = {8.5, 7.5, 8},
	[390] = {8, 7.5, 8.5},
	[391] = {8, 7, 9},
	[392] = {8, 7.5, 8.5},
	[393] = {8.5, 7, 8.5},
	[394] = {8, 8, 8},
	[395] = {8.5, 8, 7.5},
	[396] = {7, 8.5, 8.5},
	[397] = {8, 8, 8},
	[398] = {8, 7.5, 8.5},
	[399] = {7.5, 8, 8.5},
	[400] = {7, 8.5, 8.5},
	[401] = {8.5, 8, 7.5},
	[402] = {8.5, 8, 7.5},
	[403] = {7.5, 8, 8.5},
	[404] = {8, 7.5, 8.5},
	[405] = {7.5, 8, 8.5},
	[406] = {8.5, 7.5, 8},
	[407] = {7, 8.5, 8.5},
	[408] = {7.5, 8, 8.5},
	[409] = {7, 8, 9},
	[410] = {8, 7.5, 8.5},
	[411] = {8, 8, 8},
	[412] = {7, 8.5, 8.5},
	[413] = false,
	[414] = {8, 8, 8},
	[415] = {7.5, 8.5, 8},
	[416] = {8, 8, 8},
	[417] = {8, 7.5, 8.5},
	[418] = {7.5, 8, 8.5},
	[419] = {8.5, 7.5, 8},
	[420] = {8.5, 7.5, 8},
	[421] = {8, 8.5, 7.5},
	[422] = {7.5, 8.5, 8},
	[423] = {8.5, 8.5, 7},
	[424] = {8.5, 7, 8.5},
	[425] = {7.5, 8, 8.5},
	[426] = false,
	[427] = {7, 8.5, 8.5},
	[428] = {7, 8.5, 8.5},
	[429] = {7.5, 8.5, 8},
	[430] = {8, 8.5, 7.5},
	[431] = {7.5, 8, 8.5},
	[432] = {8, 8, 8},
	[433] = {7.5, 8, 8.5},
	[434] = {8, 8, 8},
	[435] = false,
	[436] = false,
	[437] = {8, 8, 8},
	[438] = {7.5, 8, 8.5},
	[439] = {8.5, 8, 7.5},
	[440] = {8, 8, 8},
	[441] = {8, 7, 9},
	[442] = {9, 6.5, 8.5},
	[443] = {8, 8, 8},
	[444] = {8, 8, 8},
	[445] = {8, 8, 8},
	[446] = {8.5, 8, 7.5},
	[447] = {8, 7.5, 8.5},
	[448] = {8, 7, 9},
	[449] = {8, 8, 8},
	[450] = {9, 8, 7},
	[451] = false,
	[452] = {8, 8, 8},
	[453] = {9, 8, 7},
	[454] = {8, 7.5, 8.5},
	[455] = {8, 8, 8},
	[456] = {8, 8.5, 7.5},
	[457] = {9, 8, 7},
	[458] = {8.5, 8.5, 7},
	[459] = {7, 8.5, 8.5},
	[460] = {7.5, 8.5, 8},
	[461] = {9, 8, 7},
	[462] = {8, 8, 8},
	[463] = {9, 9, 6},
	[464] = {8, 8, 8},
	[465] = {7, 8.5, 8.5},
	[466] = {7.5, 8, 8.5},
	[467] = {7.5, 8.5, 8},
	[468] = {7.5, 8.5, 8},
	[469] = {7, 8.5, 8.5},
	[470] = {7, 8.5, 8.5},
	[471] = {8.5, 7.5, 8},
	[472] = {8.5, 7.5, 8},
	[473] = {9, 7.5, 7.5},
	[474] = {6, 8, 10},
	[475] = {8.5, 7, 8.5},
	[476] = {7.5, 7.5, 9},
	[477] = {7.5, 7.5, 9},
	[478] = {8.5, 8, 7.5},
	[479] = {8, 6.5, 9.5},
	[480] = {8, 8.5, 7.5},
	[481] = false,
	[482] = {7.5, 8, 8.5},
	[483] = {8.5, 7.5, 8},
	[484] = {7, 8.5, 8.5},
	[485] = {9, 7.5, 7.5},
	[486] = {8, 7.5, 8.5},
	[487] = {8, 8, 8},
	[488] = {7.5, 8, 8.5},
	[489] = {8, 8.5, 7.5},
	[490] = false,
	[491] = {7, 9, 8},
	[492] = {8, 8.5, 7.5},
	[493] = {9.5, 8.5, 6},
	[494] = {8, 8, 8},
	[495] = {8.5, 7.5, 8},
	[496] = {9.5, 8.5, 6},
	[497] = {8.5, 7, 8.5},
	[498] = {8.5, 8, 7.5},
	[499] = {8, 7.5, 8.5},
	[500] = {8, 8, 8},
	[501] = false,
	[502] = {8.5, 7.5, 8},
	[503] = {7.5, 7.5, 9},
	[504] = {8, 8.5, 7.5},
	[505] = {7.5, 8, 8.5},
	[506] = {7, 8.5, 8.5},
	[507] = {7.5, 8.5, 8},
	[508] = {8, 8, 8},
	[509] = {8, 8, 8},
	[510] = {8.5, 7.5, 8},
	[511] = {7.5, 8, 8.5},
	[512] = {7.5, 8.5, 8},
	[513] = {8, 8, 8},
	[514] = {8, 8, 8},
	[515] = {8, 8, 8},
	[516] = false,
	[517] = {8, 8, 8},
	[518] = {9, 8.5, 6.5},
	[519] = {8.5, 8, 7.5},
	[520] = false,
	[521] = {7, 9, 8},
	[522] = false,
	[523] = {9, 8, 7},
	[524] = false,
	[525] = {8, 8, 8},
	[526] = false,
	[527] = false,
	[528] = {7.5, 8, 8.5},
	[529] = {8, 8, 8},
	[530] = {8, 8, 8},
	[531] = false,
	[532] = {8.5, 9, 6.5},
	[533] = false,
	[534] = {7.5, 8.5, 8},
	[535] = {8, 8, 8},
	[536] = {8.5, 8, 7.5},
	[537] = {8.5, 8, 7.5},
	[538] = {8.5, 8.5, 7},
	[539] = {8, 7.5, 8.5},
	[540] = {8, 7.5, 8.5},
	[541] = {8.5, 7, 8.5},
	[542] = {8.5, 7.5, 8},
	[543] = {7.5, 8.5, 8},
	[544] = {8.5, 8.5, 7},
	[545] = {8, 8, 8},
	[546] = {7.5, 8.5, 8},
	[547] = {8, 7, 9},
	[548] = {7.5, 8.5, 8},
	[549] = {8, 8, 8},
	[550] = {8, 7.5, 8.5},
	[551] = false,
	[552] = {7.5, 8.5, 8},
	[553] = {8, 7.5, 8.5},
	[554] = {7.5, 8.5, 8},
	[555] = {8.5, 7, 8.5},
	[556] = {7.5, 8.5, 8},
	[557] = {7.5, 8.5, 8},
	[558] = {8, 8, 8},
	[559] = {7.5, 9, 7.5},
	[560] = {8.5, 7.5, 8},
	[561] = false,
	[562] = {7.5, 8, 8.5},
	[563] = false,
	[564] = {9.5, 7.5, 7},
	[565] = {8.5, 7.5, 8},
	[566] = {7.5, 7.5, 9},
	[567] = {7.5, 8, 8.5},
	[568] = {9.5, 8.5, 6},
	[569] = {8.5, 7.5, 8},
	[570] = {8, 8, 8},
	[571] = {7.5, 8, 8.5},
	[572] = {8.5, 8, 7.5},
	[573] = {9, 7, 8},
	[574] = false,
	[575] = false,
	[576] = false,
	[577] = false,
	[578] = false,
	[579] = false,
	[580] = false,
	[581] = false,
	[582] = false,
	[583] = false,
	[584] = false,
	[585] = false,
	[586] = false,
	[587] = false,
	[588] = false,
	[589] = false,
	[590] = false,
	[591] = false,
	[592] = false,
	[593] = false,
	[594] = false,
	[595] = false,
	[596] = false,
	[597] = false,
	[598] = false,
	[599] = false,
	[600] = false,
	[601] = false,
	[602] = false,
	[603] = false,
	[604] = false,
	[605] = false,
	[606] = false,
	[607] = false,
	[608] = false,
	[609] = false,
	[610] = false,
	[611] = false,
	[612] = false,
	[613] = false,
	[614] = false,
	[615] = false,
	[616] = false,
	[617] = false,
	[618] = false,
	[619] = false,
	[620] = false,
	[621] = false,
	[622] = false,
	[623] = false,
	[624] = false,
	[625] = false,
	[626] = {7.5, 8, 8.5},
	[627] = {8.5, 8.5, 7},
	[628] = {8.5, 8, 7.5},
	[629] = {8.5, 8, 7.5},
	[630] = {8, 8, 8},
	[631] = {7.5, 8, 8.5},
	[632] = {7.5, 8, 8.5},
	[633] = {8, 8, 8},
	[634] = {7, 8.5, 8.5},
	[635] = {7.5, 8, 8.5},
	[636] = false,
	[637] = {8, 8, 8},
	[638] = {8.5, 7, 8.5},
	[639] = {8, 7.5, 8.5},
	[640] = {8, 7, 9},
	[641] = {8, 7, 9},
	[642] = false,
	[643] = false,
	[644] = {8, 7.5, 8.5},
	[645] = {8, 8, 8},
	[646] = {8, 8, 8},
	[647] = {8, 8, 8},
	[648] = {9, 7.5, 7.5},
	[649] = {9, 7.5, 7.5},
	[650] = {8.5, 8, 7.5},
	[651] = false,
	[652] = {8, 8, 8},
	[653] = false,
	[654] = false,
	[655] = false,
	[656] = false,
	[657] = false,
	[658] = false,
	[659] = false,
	[660] = false,
	[661] = false,
	[662] = false,
	[663] = false,
	[664] = false,
	[665] = {7.5, 8.5, 8},
	[666] = {8, 8, 8},
	[667] = false,
	[668] = false,
	[669] = false,
	[670] = false,
	[671] = {8, 8, 8},
	[672] = false,
	[673] = false,
	[674] = false,
	[675] = {8, 7.5, 8.5},
	[676] = false,
	[677] = {8, 8, 8},
	[678] = {8, 8, 8},
	[679] = {8, 8, 8},
	[680] = {8, 8, 8},
	[681] = false,
	[682] = false,
	[683] = false,
	[684] = false,
	[685] = false,
	[686] = false,
	[687] = false,
	[688] = false,
	[689] = false,
	[690] = false,
	[691] = false,
	[692] = false,
	[693] = false,
	[694] = false,
	[695] = false,
	[696] = false,
	[697] = false,
	[698] = false,
	[699] = {7, 8.5, 8.5},
	[700] = false,
	[701] = false,
	[702] = {8.5, 7.5, 8},
	[703] = {8, 8, 8},
	[704] = false,
	[705] = {8, 8.5, 7.5},
	[706] = {8, 8, 8},
	[707] = {8, 8, 8},
	[708] = {8, 7.5, 8.5},
	[709] = {8, 7.5, 8.5},
	[710] = {8, 8, 8},
	[711] = {8, 8, 8},
	[712] = {8, 8, 8},
	[713] = {9, 7.5, 7.5},
	[714] = {7, 8.5, 8.5},
	[715] = {8, 8, 8},
	[716] = {7, 8.5, 8.5},
	[717] = {7.5, 8.5, 8},
	[718] = {8, 8, 8},
	[719] = false,
	[720] = false,
	[721] = false,
	[722] = {7.5, 8.5, 8},
	[723] = {9, 7.5, 7.5},
	[724] = {8, 8, 8},
	[725] = {8, 8, 8},
	[726] = {7, 8.5, 8.5},
	[727] = {8, 8, 8},
	[728] = {8, 8, 8},
	[729] = {8, 7, 9},
	[730] = {8, 7, 9},
	[731] = {7, 8.5, 8.5},
	[732] = {8, 8.5, 7.5},
	[733] = {8, 8, 8},
	[734] = false,
	[735] = false,
	[736] = false,
	[737] = {6.5, 8, 9.5},
	[738] = false,
	[739] = {7, 8, 9},
	[740] = {8, 7.5, 8.5},
	[741] = {8, 8, 8},
	[742] = {8, 8, 8},
	[743] = {9.5, 8.5, 6},
	[744] = {8.5, 7, 8.5},
	[745] = {8, 8, 8},
	[746] = {8.5, 9, 6.5},
	[747] = {7.5, 8.5, 8},
	[748] = {8, 8.5, 7.5},
	[749] = {8, 8, 8},
	[750] = {8, 8, 8},
	[751] = {8, 7.5, 8.5},
	[752] = {9, 7.5, 7.5},
	[753] = {7.5, 8.5, 8},
	[754] = {8, 8, 8},
	[755] = {9, 6.5, 8.5},
	[756] = {8.5, 7, 8.5},
	[757] = {8.5, 8, 7.5},
	[758] = {7.5, 8.5, 8},
	[759] = false,
	[760] = false,
	[761] = false,
	[762] = false,
	[763] = false,
	[764] = false,
	[765] = false,
	[766] = false,
	[767] = false,
	[768] = false,
	[769] = false,
	[770] = false,
	[771] = false,
	[772] = false,
	[773] = false,
	[774] = false,
	[775] = false,
	[776] = false,
	[777] = false,
	[778] = false,
	[779] = false,
	[780] = false,
	[781] = false,
	[782] = false,
	[783] = false,
	[784] = false,
	[785] = false,
	[786] = false,
	[787] = false,
	[788] = false,
	[789] = false,
	[790] = false,
	[791] = false,
	[792] = {8, 8.5, 7.5},
	[793] = false,
	[794] = false,
	[795] = false,
	[796] = false,
	[797] = false,
	[798] = false,
	[799] = false,
	[800] = {8, 8, 8},
	[801] = false,
	[802] = {8.5, 8.5, 7},
	[803] = false,
	[804] = false,
	[805] = false,
	[806] = false,
	[807] = false,
	[808] = false,
	[809] = false,
	[810] = false,
	[811] = false,
	[812] = false,
	[813] = false,
	[814] = false,
	[815] = false,
	[816] = false,
	[817] = {8.5, 8, 7.5},
	[818] = {8, 8.5, 7.5},
	[819] = {7.5, 8.5, 8},
	[820] = {8, 8, 8},
	[821] = {8, 8, 8},
	[822] = false,
	[823] = {8, 8, 8},
	[824] = {8, 8, 8},
	[825] = {8, 8, 8},
	[826] = {8, 8, 8},
	[827] = {8, 8, 8},
	[828] = {8, 8, 8},
	[829] = {8, 8, 8},
	[830] = {8, 8, 8},
	[831] = {8, 8, 8},
	[832] = {8, 8, 8},
	[833] = {8, 8, 8},
	[834] = {8.5, 8, 7.5},
	[835] = {8, 8, 8},
	[836] = {7.5, 7, 9.5},
	[837] = {8.5, 8, 7.5},
	[838] = {8, 8, 8},
	[839] = false,
	[840] = false,
	[841] = false,
	[842] = false,
	[843] = false,
	[844] = {8, 8.5, 7.5},
	[845] = {8, 8, 8},
	[846] = {6, 8, 10},
	[847] = {8, 8, 8},
	[848] = {8, 7, 9},
	[849] = {8, 8, 8},
	[850] = {8, 8, 8},
	[851] = {7.5, 8, 8.5},
	[852] = false,
	[853] = false,
	[854] = false,
	[855] = {7.5, 8.5, 8},
	[856] = {8, 8, 8},
	[857] = false,
	[858] = false,
	[859] = false,
	[860] = false,
	[861] = false,
	[862] = false,
	[863] = false,
	[864] = false,
	[865] = false,
	[866] = false,
	[867] = false,
	[868] = {8, 8, 8},
	[869] = false,
	[870] = false,
	[871] = false,
	[872] = {8, 8, 8},
	[873] = {8, 8, 8},
	[874] = {8, 8, 8},
	[875] = {8, 8, 8},
	[876] = {8, 8, 8},
	[877] = {8, 8, 8},
	[878] = {8, 8, 8},
	[879] = {8, 8, 8},
	[880] = {8, 8, 8},
	[881] = {8, 8, 8},
	[882] = {8, 8, 8},
	[883] = {8, 8, 8},
	[884] = {8, 8, 8},
	[885] = {8, 8, 8},
	[886] = {8, 8, 8},
	[887] = {8, 8, 8},
	[888] = {8, 8, 8},
	[889] = {8, 8, 8},
	[890] = {8, 8, 8},
	[891] = {8, 8, 8},
	[892] = {8, 8, 8},
	[893] = {8, 8, 8},
	[894] = {8, 8, 8},
	[895] = {8, 8, 8},
	[896] = {8, 8, 8},
	[897] = {8, 8, 8},
	[898] = {8, 8, 8},
	[899] = {8, 8, 8},
	[900] = {8, 8, 8},
	[901] = {8, 8, 8},
	[902] = {8, 8, 8},
	[903] = {7.5, 9, 7.5},
	[904] = {8, 8, 8},
	[905] = {8, 8, 8},
	[906] = {8, 8, 8},
	[907] = {8, 8, 8},
	[908] = {8, 8, 8},
	[909] = {8, 8, 8},
	[910] = false,
	[911] = {8, 8.5, 7.5},
	[912] = {8, 8.5, 7.5},
	[913] = {8, 8.5, 7.5},
	[914] = false,
	[915] = {8, 8, 8},
	[916] = {8, 8, 8},
	[917] = {8, 8, 8},
	[918] = false,
	[919] = false,
	[920] = false,
	[921] = {8, 8, 8},
	[922] = {8, 8, 8},
	[923] = {8.5, 7.5, 8},
	[924] = {8, 8, 8},
	[925] = {8, 8, 8},
	[926] = {8, 8, 8},
	[927] = {8, 8, 8},
	[928] = {8, 8, 8},
	[929] = {8, 8, 8},
	[930] = false,
	[931] = {8, 8, 8},
	[932] = {8, 8, 8},
	[933] = {8, 8, 8},
	[934] = {8, 8, 8},
	[935] = {8, 8, 8},
	[936] = {8, 8, 8},
	[937] = {8, 8, 8},
	[938] = {8, 8, 8},
	[939] = {8, 8, 8},
	[940] = false,
	[941] = {8, 8, 8},
	[942] = {8, 8, 8},
	[943] = {8, 8, 8},
	[944] = {8, 8, 8},
	[945] = {8, 8, 8},
	[946] = {8, 8, 8},
	[947] = {8, 8, 8},
	[948] = {8, 8, 8},
	[949] = {8, 8, 8},
	[950] = {8, 8, 8},
	[951] = {8, 8, 8},
	[952] = {8, 8, 8},
	[953] = {8, 8, 8},
	[954] = {8, 8, 8},
	[955] = {8, 8, 8},
	[956] = {8, 8, 8},
	[957] = {8, 8, 8},
	[958] = {8, 8, 8},
	[959] = {8, 8, 8},
	[960] = {8, 8, 8},
	[961] = {8, 8, 8},
	[962] = {8, 8, 8},
	[963] = {8, 8, 8},
	[964] = {8, 8, 8},
	[965] = {8, 8, 8},
	[966] = {8, 8, 8},
	[967] = {8, 8, 8},
	[968] = {8, 8, 8},
	[969] = {8, 8, 8},
	[970] = {8, 8, 8},
	[971] = {8, 8, 8},
	[972] = {8, 8, 8},
	[973] = {8, 8, 8},
	[974] = {8, 8, 8},
	[975] = {8, 8, 8},
	[976] = {8, 8, 8},
	[977] = {8, 8, 8},
	[978] = {8, 8, 8},
	[979] = {8, 8, 8},
	[980] = {8, 8, 8},
	[981] = {8, 8, 8},
	[982] = {8, 8, 8},
	[983] = {8, 8, 8},
	[984] = {8, 8, 8},
	[985] = {8, 8, 8},
	[986] = {8, 8, 8},
	[987] = {8, 8, 8},
	[988] = {8, 8, 8},
	[989] = {8, 8, 8},
	[990] = {8, 8, 8},
	[991] = {8, 8, 8},
	[992] = {8, 8, 8},
	[993] = {8, 8, 8},
	[994] = {8, 8, 8},
	[995] = {8, 8, 8},
	[996] = {8, 8, 8},
	[997] = {8, 8, 8},
	[998] = {8, 8, 8},
	[999] = {8, 8, 8},
	[1000] = {8, 8, 8},
	[1001] = {8, 8, 8},
	[1002] = {8, 8, 8},
	[1003] = {8, 8, 8},
	[1004] = {8, 8, 8},
	[1005] = {8, 8, 8},
	[1006] = {8, 8, 8},
	[1007] = {8, 8, 8},
	[1008] = {8, 8, 8},
	[1009] = {8, 8, 8},
	[1010] = {8, 8, 8},
	[1011] = {8, 8, 8},
	[1012] = {8, 8, 8},
	[1013] = {9, 7.5, 7.5},
	[1014] = false,
	[1015] = false,
	[1016] = false,
	[1017] = false,
	[1018] = false,
	[1019] = false,
	[1020] = false,
	[1021] = false,
	[1022] = false,
	[1023] = false,
	[1024] = false,
	[1025] = false,
	[1026] = false,
	[1027] = false,
	[1028] = false,
	[1029] = false,
	[1030] = false,
	[1031] = false,
	[1032] = false,
	[1033] = false,
	[1034] = false,
	[1035] = false,
	[1036] = false,
	[1037] = false,
	[1038] = false,
	[1039] = {7.5, 7.5, 9},
	[1040] = {8, 8, 8},
	[1041] = false,
	[1042] = {6.75, 10.5, 6.75},
	[1043] = false,
	[1044] = false,
	[1045] = false,
	[1046] = false,
	[1047] = false,
	[1048] = false,
	[1049] = false,
	[1050] = false,
	[1051] = false,
	[1052] = false,
	[1053] = false,
	[1054] = false,
	[1055] = false,
	[1056] = false,
	[1057] = false,
	[1058] = false,
	[1059] = false,
	[1060] = false,
	[1061] = {8, 8, 8},
	[1062] = {8, 7.5, 8.5},
	[1063] = {8.5, 8.5, 7},
	[1064] = false,
	[1065] = {8.5, 8.5, 7},
	[1066] = {8, 8, 8},
	[1067] = {8.5, 7.5, 8},
	[1068] = {8, 8, 8},
	[1069] = false,
	[1070] = false,
	[1071] = false,
	[1072] = false,
	[1073] = {8, 8, 8},
	[1074] = false,
	[1075] = false,
	[1076] = false,
	[1077] = false,
	[1078] = false,
	[1079] = false,
	[1080] = false,
	[1081] = false,
	[1082] = false,
	[1083] = false,
	[1084] = false,
	[1085] = false,
	[1086] = false,
	[1087] = false,
	[1088] = false,
	[1089] = false,
	[1090] = false,
	[1091] = false,
	[1092] = false,
	[1093] = false,
	[1094] = false,
	[1095] = false,
	[1096] = false,
	[1097] = false,
	[1098] = false,
	[1099] = false,
	[1100] = false,
	[1101] = false,
	[1102] = false,
	[1103] = false,
	[1104] = false,
	[1105] = false,
	[1106] = false,
	[1107] = false,
	[1108] = false,
	[1109] = false,
	[1110] = false,
	[1111] = false,
	[1112] = false,
	[1113] = false,
	[1114] = false,
	[1115] = false,
	[1116] = false,
	[1117] = {7.5, 8.5, 8.5},
	[1118] = false,
	[1119] = false,
	[1120] = false,
	[1121] = false,
	[1122] = false,
	[1123] = false,
	[1124] = {8, 8, 8},
	[1125] = {8, 8, 8},
	[1126] = {8, 8, 8},
	[1127] = {7.5, 8.5, 8},
	[1128] = {8, 8, 8},
	[1129] = {11.5, 15.5, 7.5},
	[1130] = {8, 8, 8},
	[1131] = {8, 8, 8},
	[1132] = {8, 8, 8},
	[1133] = {8, 8, 8},
	[1134] = {8, 8, 8},
	[1135] = {8, 8, 8},
	[1136] = {8, 8, 8},
	[1137] = {8, 8, 8},
	[1138] = {8, 8, 8},
	[1139] = {8, 8, 8},
	[1140] = {8, 8, 8},
	[1141] = {8, 8, 8},
	[1142] = {8.5, 7.5, 8},
	[1143] = {8, 8, 8},
	[1144] = {8, 8, 8},
	[1145] = {8, 8, 8},
	[1146] = {8, 8, 8},
	[1147] = {8, 8, 8},
	[1148] = false,
	[1149] = {8, 8, 8},
	[1150] = {8, 8, 8},
	[1151] = {8, 8, 8},
	[1152] = {7.5, 8.5, 8},
	[1153] = {8, 8, 8},
	[1154] = {8, 8, 8},
	[1155] = {8, 8.5, 7.5},
	[1156] = {8, 8, 8},
	[1157] = {8, 8, 8},
	[1158] = {8, 8, 8},
	[1159] = {7.5, 8.5, 8},
	[1160] = {8.5, 8, 7.5},
	[1161] = {8, 8.5, 7.5},
	[1162] = {7, 9, 8},
	[1163] = {9, 8, 7},
	[1164] = {7.5, 8, 8.5},
	[1165] = {8, 8.5, 7.5},
	[1166] = {8, 8.5, 7.5},
	[1167] = {8, 8.5, 7.5},
	[1168] = {8, 8, 8},
	[1169] = false,
	[1170] = false,
	[1171] = false,
	[1172] = false,
	[1173] = false,
	[1174] = {7.5, 8.5, 8},
	[1175] = {8, 8, 8},
	[1176] = {8, 8, 8},
	[1177] = {9, 8, 7},
	[1178] = {8, 8, 8},
	[1179] = {8, 8.5, 7.5},
	[1180] = {7, 8.5, 8.5},
	[1181] = {7.5, 8, 8.5},
	[1182] = {8.5, 7.5, 8},
	[1183] = {8, 8, 8},
	[1184] = {8.25, 8, 7.75},
	[1185] = {8, 8, 8},
	[1186] = false,
	[1187] = {11.625, 15.375, 7.625},
	[1188] = {11.375, 15.125, 7.75},
	[1189] = {11.875, 16, 7.25},
	[1190] = {11.125, 14.25, 7.875},
	[1191] = {12, 15.75, 7},
	[1192] = {11.625, 15, 7.375},
	[1193] = {11, 14.5, 7.5},
	[1194] = {11.25, 15.25, 7.875},
	[1195] = {11, 15, 8},
	[1196] = {8, 8, 8},
	[1197] = {8, 8, 8},
	[1198] = {8, 8, 8},
	[1199] = false,
	[1200] = {8.25, 8, 7.75},
	[1201] = {7, 8.5, 8.5},
	[1202] = {8, 7.5, 8.5},
	[1203] = false,
	[1204] = {8.5, 7.5, 8},
	[1205] = {8.25, 8, 7.75},
	[1206] = {7.5, 8, 8.5},
	[1207] = {7.5, 8.5, 8.5},
	[1208] = {7.5, 8, 8.5},
	[1209] = {7.5, 8, 8.5},
	[1210] = false,
	[1211] = {7, 8.5, 8.5},
	[1212] = {7, 8.5, 8.5},
	[1213] = {7, 8.5, 8.5},
	[1214] = false,
	[1215] = false,
	[1216] = false,
	[1217] = false,
	[1218] = false,
	[1219] = false,
	[1220] = false,
	[1221] = false,
	[1222] = false,
	[1223] = false,
	[1224] = false,
	[1225] = false,
	[1226] = {7.5, 8.5, 8},
	[1227] = {8.5, 8, 7.5},
	[1228] = {8, 8.25, 7.75},
	[1229] = {7.75, 8, 8.25},
	[1230] = {8.25, 8.25, 7.5},
	[1231] = {8, 8, 8},
	[1232] = {7.75, 8.25, 8},
	[1233] = {8.25, 8.5, 7.25},
	[1234] = {8.25, 8, 7.75},
	[1235] = {8, 8, 8},
	[1236] = {7.5, 8.25, 8.25},
	[1237] = {8, 8.25, 7.75},
	[1238] = {8.5, 8.5, 7},
	[1239] = false,
	[1240] = false,
	[1241] = false,
	[1242] = false,
	[1243] = {8, 8, 8},
	[1244] = {8, 8, 8},
	[1245] = {8, 8, 8},
	[1246] = false,
	[1247] = {11, 16, 7},
	[1248] = {8.25, 8, 7.75},
	[1249] = false,
	[1250] = false,
	[1251] = false,
	[1252] = false,
	[1253] = false,
	[1254] = false,
	[1255] = {7.75, 8.375, 7.875},
	[1256] = {8, 8, 8},
	[1257] = {8, 8, 8},
	[1258] = {8, 9, 7},
	[1259] = {9, 8, 8},
	[1260] = false,
	[1261] = false,
	[1262] = false,
	[1263] = false,
	[1264] = false,
	[1265] = false,
	[1266] = {8, 8.25, 7.75},
	[1267] = {11.25, 15.25, 7},
	[1268] = {9, 8.375, 6.625},
	[1269] = {8, 9.25, 6.75},
	[1270] = false,
	[1271] = {8, 7.5, 8.5},
	[1272] = false,
	[1273] = false,
	[1274] = false,
	[1275] = false,
	[1276] = {8, 8, 8},
	[1277] = {8.5, 8, 7.5},
	[1278] = {8, 8.25, 7.25},
	[1279] = {8.5, 8, 7.5},
	[1280] = {8.5, 8, 7.5},
	[1281] = {8, 8.5, 8},
	[1282] = {8, 9.25, 6.75},
	[1283] = {8, 9.5, 6.5},
	[1284] = {9.25, 8, 6.75},
	[1285] = {8, 7.5, 8.5},
	[1286] = {7.875, 7.875, 8.25},
	[1287] = {8, 9, 7.25},
	[1288] = {9.5, 8, 6.5},
	[1289] = {8, 9.5, 7},
	[1290] = {8.25, 8, 7.75},
	[1291] = {9.5, 8, 6.5},
	[1292] = {8.5, 8, 8},
	[1293] = {8, 8, 8.5},
	[1294] = false,
	[1295] = {8, 8.75, 7.25},
	[1296] = {9.25, 8, 7},
	[1297] = {8, 8, 8.25},
	[1298] = {8, 8, 8},
	[1299] = {8, 8, 8},
	[1300] = {8, 8, 8},
	[1301] = {8, 8, 8},
	[1302] = false,
	[1303] = {8.25, 8.25, 7.5},
	[1304] = {7, 8.5, 8.5},
	[1305] = {8.5, 8, 7.5},
	[1306] = false,
	[1307] = false,
	[1308] = false,
	[1309] = false,
	[1310] = false,
	[1311] = {11.25, 15.25, 7.375},
	[1312] = false,
	[1313] = false,
	[1314] = false,
	[1315] = false,
	[1316] = false,
	[1317] = {11.25, 15.25, 6.75},
	[1318] = false,
	[1319] = {11.25, 15.25, 7.35},
	[1320] = {8, 8, 8},
	[1321] = {8, 8.5, 7.5},
	[1322] = {8.5, 8.5, 7},
	[1323] = {7.5, 8.25, 8.25},
	[1324] = {8, 8, 8},
	[1325] = {8, 8, 8},
	[1326] = {8, 8, 8},
	[1327] = false,
	[1328] = {8, 8, 8},
	[1329] = {8, 8, 8},
	[1330] = {7.5, 8, 8.5},
	[1331] = {8, 8, 8},
	[1332] = {8, 8, 8},
	[1333] = {7.75, 8.5, 7.75},
	[1334] = {7.5, 8, 8.5},
	[1335] = {8, 8, 8},
	[1336] = {8, 8, 8},
	[1337] = {7.5, 9, 7.5},
	[1338] = {8.5, 7.5, 8},
	[1339] = {13, 19.5, 5},
	[1340] = false,
	[1341] = false,
	[1342] = false,
	[1343] = {8, 8, 8},
	[1344] = {8.25, 8, 7.75},
	[1345] = {8, 8, 8},
	[1346] = {8, 8, 8},
	[1347] = false,
	[1348] = {8, 8, 8},
	[1349] = {7.75, 8.25, 8},
	[1350] = {8, 8, 8},
	[1351] = {8, 8, 8},
	[1352] = {33, 8, 8},
	[1353] = false,
	[1354] = {12, 15.25, 7.35},
    [1355] = false,
    [1356] = false,
    [1357] = false,
    [1358] = false,
    [1359] = false,
    [1360] = false,
    [1361] = false,
    [1362] = false,
    [1363] = false,
    [1364] = {8.6, 7.8, 7.6}, -- NEW: Murkalot
    }

lib.breedData.speciesToAvailableBreeds = {
    [1] = false,
    [2] = false,
    [3] = false,
    [4] = false,
    [5] = false,
    [6] = false,
    [7] = false,
    [8] = false,
    [9] = false,
    [10] = false,
    [11] = false,
    [12] = false,
    [13] = false,
    [14] = false,
    [15] = false,
    [16] = false,
    [17] = false,
    [18] = false,
    [19] = false,
    [20] = false,
    [21] = false,
    [22] = false,
    [23] = false,
    [24] = false,
    [25] = false,
    [26] = false,
    [27] = false,
    [28] = false,
    [29] = false,
    [30] = false,
    [31] = false,
    [32] = false,
    [33] = false,
    [34] = false,
    [35] = false,
    [36] = false,
    [37] = false,
    [38] = false,
    [39] = {11},
    [40] = {8},
    [41] = {4},
    [42] = {7},
    [43] = {3},
    [44] = {5},
    [45] = {3},
    [46] = {12},
    [47] = {3, 5},
    [48] = false,
    [49] = {3},
    [50] = {11},
    [51] = {3, 5},
    [52] = {3, 10, 11, 12},
    [53] = false,
    [54] = false,
    [55] = {3, 5, 6, 9},
    [56] = {8},
    [57] = {4},
    [58] = {8},
    [59] = {9},
    [60] = false,
    [61] = false,
    [62] = false,
    [63] = false,
    [64] = {9},
    [65] = {12},
    [66] = false,
    [67] = {3, 8, 10},
    [68] = {3, 6, 7},
    [69] = {3, 10, 11},
    [70] = {3, 5, 12},
    [71] = false,
    [72] = {3, 5, 11},
    [73] = false,
    [74] = {11},
    [75] = {5},
    [76] = false,
    [77] = {3},
    [78] = {12},
    [79] = false,
    [80] = false,
    [81] = false,
    [82] = false,
    [83] = {8},
    [84] = {3, 10, 11, 12},
    [85] = {9},
    [86] = {7},
    [87] = {5},
    [88] = false,
    [89] = {6},
    [90] = {7},
    [91] = false,
    [92] = {3},
    [93] = {4},
    [94] = {5},
    [95] = {3},
    [96] = false,
    [97] = false,
    [98] = false,
    [99] = false,
    [100] = false,
    [101] = false,
    [102] = false,
    [103] = false,
    [104] = false,
    [105] = false,
    [106] = {10},
    [107] = {3},
    [108] = false,
    [109] = false,
    [110] = false,
    [111] = {12},
    [112] = false,
    [113] = false,
    [114] = {12},
    [115] = false,
    [116] = {12},
    [117] = {3},
    [118] = {3},
    [119] = {3},
    [120] = {3},
    [121] = {3},
    [122] = {5},
    [123] = false,
    [124] = {3},
    [125] = {5},
    [126] = {10},
    [127] = {7},
    [128] = {3},
    [129] = false,
    [130] = {3},
    [131] = {8},
    [132] = {6},
    [133] = false,
    [134] = false,
    [135] = false,
    [136] = {3, 7, 10, 12},
    [137] = {3, 5, 11},
    [138] = {3, 12},
    [139] = {3, 8, 12},
    [140] = {3, 4, 12},
    [141] = {3, 6, 12},
    [142] = {3, 5},
    [143] = {3, 5, 8},
    [144] = {3, 5, 11},
    [145] = {3, 5, 6, 8},
    [146] = {3, 5, 9, 12},
    [147] = false,
    [148] = false,
    [149] = {9},
    [150] = false,
    [151] = false,
    [152] = false,
    [153] = {7},
    [154] = false,
    [155] = {7},
    [156] = {3},
    [157] = {3},
    [158] = {3},
    [159] = {6},
    [160] = {4},
    [161] = false,
    [162] = {10},
    [163] = {8},
    [164] = {3},
    [165] = {9},
    [166] = {7},
    [167] = {3, 6, 9},
    [168] = {5},
    [169] = {5},
    [170] = {7},
    [171] = {7},
    [172] = {10},
    [173] = {7},
    [174] = {3},
    [175] = {5},
    [176] = false,
    [177] = false,
    [178] = false,
    [179] = {7},
    [180] = {7},
    [181] = false,
    [182] = false,
    [183] = {3},
    [184] = false,
    [185] = false,
    [186] = {3, 4, 5, 8},
    [187] = {8},
    [188] = {6},
    [189] = {3},
    [190] = {6, 7, 12},
    [191] = {3},
    [192] = {9},
    [193] = {4},
    [194] = {3, 5, 8, 9, 11},
    [195] = {5, 8, 9, 11},
    [196] = {7},
    [197] = {8},
    [198] = {11},
    [199] = {10},
    [200] = {5},
    [201] = {7},
    [202] = {7},
    [203] = {12},
    [204] = {3},
    [205] = {7},
    [206] = {3, 9, 11},
    [207] = {8},
    [208] = false,
    [209] = {3},
    [210] = {5},
    [211] = {6},
    [212] = {3},
    [213] = {5},
    [214] = {3},
    [215] = {10},
    [216] = {3},
    [217] = {7},
    [218] = {4},
    [219] = false,
    [220] = {9},
    [221] = false,
    [222] = false,
    [223] = false,
    [224] = {10},
    [225] = {3},
    [226] = {4},
    [227] = {4},
    [228] = {7},
    [229] = {3},
    [230] = false,
    [231] = {3},
    [232] = {8},
    [233] = {8},
    [234] = {10},
    [235] = {10},
    [236] = {6},
    [237] = {3},
    [238] = {11},
    [239] = {4},
    [240] = {3},
    [241] = {12},
    [242] = {8},
    [243] = {10},
    [244] = {7},
    [245] = {8},
    [246] = {3},
    [247] = {6},
    [248] = {8},
    [249] = {7},
    [250] = {8},
    [251] = {3},
    [252] = false,
    [253] = {3},
    [254] = {3, 5, 8},
    [255] = {6},
    [256] = {7},
    [257] = false,
    [258] = {6},
    [259] = {12},
    [260] = {8},
    [261] = {4},
    [262] = {5},
    [263] = false,
    [264] = {8},
    [265] = {6},
    [266] = {8},
    [267] = {3},
    [268] = {4},
    [269] = false,
    [270] = {9},
    [271] = {3, 9, 10},
    [272] = {6, 9},
    [273] = false,
    [274] = false,
    [275] = false,
    [276] = false,
    [277] = {11},
    [278] = {9},
    [279] = {8},
    [280] = {3},
    [281] = {3},
    [282] = {3},
    [283] = {3},
    [284] = false,
    [285] = {10},
    [286] = {7},
    [287] = {3},
    [288] = false,
    [289] = {6},
    [290] = false,
    [291] = {12},
    [292] = {3},
    [293] = {9},
    [294] = {8},
    [295] = false,
    [296] = {3},
    [297] = {4},
    [298] = {3},
    [299] = false,
    [300] = false,
    [301] = {11},
    [302] = {7},
    [303] = {5},
    [304] = false,
    [305] = false,
    [306] = {11},
    [307] = {3},
    [308] = {3},
    [309] = {8},
    [310] = {8},
    [311] = {3},
    [312] = false,
    [313] = false,
    [314] = false,
    [315] = false,
    [316] = {3},
    [317] = {3},
    [318] = {3},
    [319] = {10},
    [320] = {7},
    [321] = {6},
    [322] = false,
    [323] = {8},
    [324] = false,
    [325] = {5, 8, 10},
    [326] = false,
    [327] = false,
    [328] = {4},
    [329] = {8},
    [330] = {10},
    [331] = {3},
    [332] = {3},
    [333] = {11},
    [334] = false,
    [335] = {12},
    [336] = {3},
    [337] = {12},
    [338] = {7},
    [339] = {12},
    [340] = {3},
    [341] = {3},
    [342] = {3},
    [343] = {3, 8},
    [344] = false,
    [345] = false,
    [346] = {3},
    [347] = {3},
    [348] = {8},
    [349] = false,
    [350] = false,
    [351] = false,
    [352] = false,
    [353] = false,
    [354] = false,
    [355] = false,
    [356] = false,
    [357] = false,
    [358] = false,
    [359] = false,
    [360] = false,
    [361] = false,
    [362] = false,
    [363] = false,
    [364] = false,
    [365] = false,
    [366] = false,
    [367] = false,
    [368] = false,
    [369] = false,
    [370] = false,
    [371] = false,
    [372] = false,
    [373] = false,
    [374] = {7, 8, 9, 10, 11, 12},
    [375] = false,
    [376] = false,
    [377] = false,
    [378] = {3, 5, 7, 9, 11, 12},
    [379] = {3, 5, 10, 11, 12},
    [380] = {3, 12},
    [381] = {9},
    [382] = false,
    [383] = {8, 11},
    [384] = false,
    [385] = {3, 5, 8, 11, 12},
    [386] = {3, 5, 11},
    [387] = {3, 5},
    [388] = {3, 6, 7},
    [389] = {3, 4, 5, 6, 7, 8, 9, 10, 11, 12},
    [390] = false,
    [391] = {3, 5, 9},
    [392] = {3, 5, 9, 11},
    [393] = {5, 6, 7, 9, 11, 12},
    [394] = false,
    [395] = {3, 6, 7},
    [396] = {8, 11},
    [397] = {3, 9, 11, 12},
    [398] = {3, 5, 9, 11},
    [399] = {3, 5, 8},
    [400] = {3, 4, 9, 11},
    [401] = {3, 6, 7},
    [402] = {3, 9, 12},
    [403] = {3, 5, 8, 10},
    [404] = {3, 12},
    [405] = {3, 4, 7},
    [406] = {3, 6, 7, 9},
    [407] = {3, 5, 8, 11},
    [408] = {3, 5, 11},
    [409] = {5, 8, 10},
    [410] = {3, 5, 9, 11},
    [411] = {3, 4},
    [412] = {3, 5, 11},
    [413] = false,
    [414] = {3, 8},
    [415] = {6, 7, 9},
    [416] = {3, 5, 8},
    [417] = {3, 5, 9, 11},
    [418] = {3, 11},
    [419] = {3, 11},
    [420] = {3, 7, 12},
    [421] = {3, 9, 12},
    [422] = {3, 5, 8},
    [423] = {3, 6, 9},
    [424] = {5, 6, 7, 9, 11, 12},
    [425] = {3, 8, 10},
    [426] = false,
    [427] = {3, 9},
    [428] = {3, 5, 8, 11},
    [429] = {4, 6, 7, 9},
    [430] = {5},
    [431] = {8, 9},
    [432] = {3, 8},
    [433] = {3, 5, 7},
    [434] = false,
    [435] = false,
    [436] = false,
    [437] = {3, 10},
    [438] = {6, 9},
    [439] = {6, 9},
    [440] = {3, 4, 8},
    [441] = {5, 7, 9},
    [442] = {6, 7, 9, 12},
    [443] = {3, 5, 7, 9, 11, 12},
    [444] = false,
    [445] = {6, 7, 9, 10},
    [446] = {3, 4, 6, 9},
    [447] = {3, 5, 9, 11, 12},
    [448] = {3, 5, 7, 9, 11, 12},
    [449] = {3, 5, 11},
    [450] = {3, 6},
    [451] = false,
    [452] = {3, 5, 10, 11, 12},
    [453] = {6, 7},
    [454] = {3, 5, 9, 11},
    [455] = {7, 8, 10},
    [456] = {3, 6, 7, 8},
    [457] = {6, 9},
    [458] = {3, 6},
    [459] = {3, 5, 8, 11},
    [460] = {3, 6, 9},
    [461] = {3},
    [462] = false,
    [463] = {6, 9},
    [464] = {3, 5, 9},
    [465] = {3, 4, 8},
    [466] = {3, 5, 7},
    [467] = {3, 6, 7, 9},
    [468] = {3, 6, 7, 9},
    [469] = {3, 4, 6, 7, 9},
    [470] = {3, 4, 7, 11},
    [471] = {3, 5, 6, 8, 9, 10},
    [472] = {3, 4, 5, 6, 7, 8, 10, 11},
    [473] = {3, 9},
    [474] = {5},
    [475] = {3, 12},
    [476] = false,
    [477] = {3, 11},
    [478] = {3, 9, 11, 12},
    [479] = {3, 11},
    [480] = {3, 6, 9},
    [481] = false,
    [482] = {3, 5},
    [483] = {3, 12},
    [484] = {3, 5, 8, 11},
    [485] = {6, 7, 9},
    [486] = false,
    [487] = {3, 5, 7, 10, 11, 12},
    [488] = {12},
    [489] = {4, 8, 10},
    [490] = false,
    [491] = {5, 8},
    [492] = {3, 6, 9},
    [493] = {3, 6, 7},
    [494] = {3, 6, 7},
    [495] = {3, 12},
    [496] = {3, 9, 12},
    [497] = {6, 7, 9, 12},
    [498] = {3, 8, 9},
    [499] = {7},
    [500] = {3, 4, 6, 7, 8, 10},
    [501] = false,
    [502] = {3, 12},
    [503] = {3, 5, 11},
    [504] = {3, 4, 10},
    [505] = {3, 5, 7, 11},
    [506] = {3, 6, 9, 11},
    [507] = {3, 9, 12},
    [508] = {3, 4, 7},
    [509] = {6, 7, 9},
    [510] = false,
    [511] = {3, 5, 11},
    [512] = {4, 6, 9, 12},
    [513] = {3, 4, 5, 6, 7, 8, 9, 10, 11, 12},
    [514] = {3, 4, 5, 6, 7, 8, 9, 10, 11, 12},
    [515] = {3, 4, 5, 6, 7, 8, 9, 10, 11, 12},
    [516] = false,
    [517] = {3, 8},
    [518] = {3, 6},
    [519] = {6, 7, 9},
    [520] = false,
    [521] = {10},
    [522] = false,
    [523] = {6, 9},
    [524] = false,
    [525] = {3, 5, 12},
    [526] = false,
    [527] = false,
    [528] = {9, 12},
    [529] = {4, 7},
    [530] = {3, 6, 7, 9},
    [531] = false,
    [532] = {4, 6},
    [533] = false,
    [534] = {3, 4, 5, 8, 10},
    [535] = {3, 9},
    [536] = {7, 9},
    [537] = {3, 4, 6, 7},
    [538] = {6, 8},
    [539] = {3, 5, 10, 11, 12},
    [540] = {3, 5, 10, 11, 12},
    [541] = {5, 6, 7, 9},
    [542] = {3, 12},
    [543] = {3, 5, 9},
    [544] = {5, 11, 12},
    [545] = {3, 5, 8},
    [546] = {6, 9, 12},
    [547] = {3, 5, 7, 9, 10, 11},
    [548] = {3, 4, 5, 6, 7, 8, 9, 10, 11, 12},
    [549] = {3, 5, 10, 11, 12},
    [550] = {3, 5, 10, 11, 12},
    [551] = false,
    [552] = {3, 4, 6, 7, 11},
    [553] = {3, 5, 10, 11, 12},
    [554] = {3, 7, 9},
    [555] = {5, 6, 7, 9},
    [556] = {6, 9, 12},
    [557] = {4, 5, 7, 10, 11},
    [558] = {8},
    [559] = {4, 6, 7, 9},
    [560] = {3, 5, 10},
    [561] = false,
    [562] = {3, 5, 8},
    [563] = false,
    [564] = {3, 6, 12},
    [565] = {3, 12},
    [566] = {3, 9, 12},
    [567] = {5, 10},
    [568] = {3, 9},
    [569] = {3, 12},
    [570] = {3, 10},
    [571] = {3, 5},
    [572] = {4, 6},
    [573] = {3, 5, 10, 11},
    [574] = false,
    [575] = false,
    [576] = false,
    [577] = false,
    [578] = false,
    [579] = false,
    [580] = false,
    [581] = false,
    [582] = false,
    [583] = false,
    [584] = false,
    [585] = false,
    [586] = false,
    [587] = false,
    [588] = false,
    [589] = false,
    [590] = false,
    [591] = false,
    [592] = false,
    [593] = false,
    [594] = false,
    [595] = false,
    [596] = false,
    [597] = false,
    [598] = false,
    [599] = false,
    [600] = false,
    [601] = false,
    [602] = false,
    [603] = false,
    [604] = false,
    [605] = false,
    [606] = false,
    [607] = false,
    [608] = false,
    [609] = false,
    [610] = false,
    [611] = false,
    [612] = false,
    [613] = false,
    [614] = false,
    [615] = false,
    [616] = false,
    [617] = false,
    [618] = false,
    [619] = false,
    [620] = false,
    [621] = false,
    [622] = false,
    [623] = false,
    [624] = false,
    [625] = false,
    [626] = {4, 5, 7, 8, 10, 11},
    [627] = {7, 10},
    [628] = {3, 10},
    [629] = {3, 4, 7},
    [630] = {3, 5, 8, 10},
    [631] = {7, 9},
    [632] = {3, 10},
    [633] = {3, 7, 9, 12},
    [634] = {3, 9},
    [635] = {3, 8, 10},
    [636] = false,
    [637] = {3, 5, 11},
    [638] = {5, 6, 7, 9},
    [639] = {3, 5, 10, 11, 12},
    [640] = {3, 5, 7, 9, 11, 12},
    [641] = {3, 5, 7, 9, 11, 12},
    [642] = false,
    [643] = false,
    [644] = {3, 5, 10, 11, 12},
    [645] = {3, 8, 9},
    [646] = {3, 5, 11, 12},
    [647] = {3, 5, 8, 10, 11},
    [648] = {3, 6, 7, 12},
    [649] = {3, 7, 8},
    [650] = {8},
    [651] = false,
    [652] = {11},
    [653] = false,
    [654] = false,
    [655] = false,
    [656] = false,
    [657] = false,
    [658] = false,
    [659] = false,
    [660] = false,
    [661] = false,
    [662] = false,
    [663] = false,
    [664] = false,
    [665] = {11},
    [666] = false,
    [667] = false,
    [668] = false,
    [669] = false,
    [670] = false,
    [671] = {8},
    [672] = false,
    [673] = false,
    [674] = false,
    [675] = {3, 5, 10, 11, 12},
    [676] = false,
    [677] = {3, 5, 8},
    [678] = {6, 9},
    [679] = {5, 11},
    [680] = {5, 11},
    [681] = false,
    [682] = false,
    [683] = false,
    [684] = false,
    [685] = false,
    [686] = false,
    [687] = false,
    [688] = false,
    [689] = false,
    [690] = false,
    [691] = false,
    [692] = false,
    [693] = false,
    [694] = false,
    [695] = false,
    [696] = false,
    [697] = false,
    [698] = false,
    [699] = {3, 9, 11, 12},
    [700] = false,
    [701] = false,
    [702] = {3, 5, 12},
    [703] = {3, 11},
    [704] = false,
    [705] = false,
    [706] = {3, 5, 8},
    [707] = {3, 5},
    [708] = {3, 5, 10, 11, 12},
    [709] = {3, 5, 11, 12},
    [710] = {3, 9, 11},
    [711] = {3, 5, 11},
    [712] = {3, 5, 11},
    [713] = {3, 9},
    [714] = {3, 4, 10, 11},
    [715] = false,
    [716] = {7, 9},
    [717] = {5, 6, 9, 12},
    [718] = {3, 8, 9},
    [719] = false,
    [720] = false,
    [721] = false,
    [722] = {3, 9, 10, 12},
    [723] = {3, 6, 9},
    [724] = {5, 10},
    [725] = {3, 11},
    [726] = {3, 5, 7},
    [727] = {3, 5, 8, 11, 12},
    [728] = {3, 5, 11, 12},
    [729] = {3, 5, 7, 9, 11, 12},
    [730] = {3, 5, 9, 11, 12},
    [731] = {7, 9},
    [732] = {8, 9},
    [733] = {3, 5, 11},
    [734] = false,
    [735] = false,
    [736] = false,
    [737] = {5, 8},
    [738] = false,
    [739] = {5, 8},
    [740] = {3, 9, 10, 11, 12},
    [741] = {3, 12},
    [742] = {3, 5},
    [743] = {3, 5, 12},
    [744] = {5, 6, 7, 9, 11, 12},
    [745] = {3, 9},
    [746] = {4, 6},
    [747] = {3, 9, 10, 12},
    [748] = {3, 5, 7, 8, 9, 10, 11, 12},
    [749] = {5, 11},
    [750] = {3, 5, 11},
    [751] = {3, 9, 11, 12},
    [752] = {3, 4, 12},
    [753] = {3, 9},
    [754] = {3, 5, 7, 8, 9, 11, 12},
    [755] = {8, 10},
    [756] = {3, 5, 9},
    [757] = {5},
    [758] = {8},
    [759] = false,
    [760] = false,
    [761] = false,
    [762] = false,
    [763] = false,
    [764] = false,
    [765] = false,
    [766] = false,
    [767] = false,
    [768] = false,
    [769] = false,
    [770] = false,
    [771] = false,
    [772] = false,
    [773] = false,
    [774] = false,
    [775] = false,
    [776] = false,
    [777] = false,
    [778] = false,
    [779] = false,
    [780] = false,
    [781] = false,
    [782] = false,
    [783] = false,
    [784] = false,
    [785] = false,
    [786] = false,
    [787] = false,
    [788] = false,
    [789] = false,
    [790] = false,
    [791] = false,
    [792] = {3, 12},
    [793] = false,
    [794] = false,
    [795] = false,
    [796] = false,
    [797] = false,
    [798] = false,
    [799] = false,
    [800] = false,
    [801] = false,
    [802] = {4},
    [803] = false,
    [804] = false,
    [805] = false,
    [806] = false,
    [807] = false,
    [808] = false,
    [809] = false,
    [810] = false,
    [811] = false,
    [812] = false,
    [813] = false,
    [814] = false,
    [815] = false,
    [816] = false,
    [817] = {7},
    [818] = {8},
    [819] = {5},
    [820] = {12},
    [821] = {11},
    [822] = false,
    [823] = {3, 5, 9, 12},
    [824] = false,
    [825] = false,
    [826] = false,
    [827] = false,
    [828] = false,
    [829] = false,
    [830] = false,
    [831] = false,
    [832] = false,
    [833] = false,
    [834] = {7},
    [835] = {5},
    [836] = {5},
    [837] = {3, 4, 5, 6, 7, 8, 9, 10, 11, 12},
    [838] = {3, 4, 5, 6, 7, 8, 9, 10, 11, 12},
    [839] = false,
    [840] = false,
    [841] = false,
    [842] = false,
    [843] = false,
    [844] = {5},
    [845] = {3, 8, 10},
    [846] = {5},
    [847] = {12},
    [848] = {3, 5, 9},
    [849] = {3},
    [850] = {3},
    [851] = {3, 5, 7},
    [852] = false,
    [853] = false,
    [854] = false,
    [855] = {3},
    [856] = {9, 12},
    [857] = false,
    [858] = false,
    [859] = false,
    [860] = false,
    [861] = false,
    [862] = false,
    [863] = false,
    [864] = false,
    [865] = false,
    [866] = false,
    [867] = false,
    [868] = {9},
    [869] = false,
    [870] = false,
    [871] = false,
    [872] = {3},
    [873] = {3},
    [874] = {3},
    [875] = {8},
    [876] = {7},
    [877] = {9},
    [878] = {3},
    [879] = {7},
    [880] = {7},
    [881] = {8},
    [882] = {9},
    [883] = {6},
    [884] = {8},
    [885] = {8},
    [886] = {9},
    [887] = {8},
    [888] = {3},
    [889] = {3},
    [890] = {3},
    [891] = {5},
    [892] = {8},
    [893] = {3},
    [894] = {5},
    [895] = {8},
    [896] = {6},
    [897] = {9},
    [898] = {3},
    [899] = {8},
    [900] = {6},
    [901] = {6},
    [902] = {9},
    [903] = {10},
    [904] = {9},
    [905] = {8},
    [906] = {5},
    [907] = {9},
    [908] = {8},
    [909] = {5},
    [910] = false,
    [911] = {7},
    [912] = {4},
    [913] = {8},
    [914] = false,
    [915] = {7},
    [916] = {8},
    [917] = {6},
    [918] = false,
    [919] = false,
    [920] = false,
    [921] = {7},
    [922] = {4},
    [923] = {6},
    [924] = {9},
    [925] = {7},
    [926] = {8},
    [927] = {5},
    [928] = {8},
    [929] = {9},
    [930] = false,
    [931] = {9},
    [932] = {6},
    [933] = {5},
    [934] = {6},
    [935] = {8},
    [936] = {3},
    [937] = {8},
    [938] = {9},
    [939] = {7},
    [940] = false,
    [941] = {8},
    [942] = {6},
    [943] = {9},
    [944] = {6},
    [945] = {7},
    [946] = {5},
    [947] = {9},
    [948] = {5},
    [949] = {8},
    [950] = {6},
    [951] = {7},
    [952] = {7},
    [953] = {6},
    [954] = {3},
    [955] = {5},
    [956] = {6},
    [957] = {8},
    [958] = {3},
    [959] = {8},
    [960] = {4},
    [961] = {4},
    [962] = {8},
    [963] = {7},
    [964] = {3},
    [965] = {3},
    [966] = {9},
    [967] = {8},
    [968] = {7},
    [969] = {9},
    [970] = {8},
    [971] = {7},
    [972] = {9},
    [973] = {8},
    [974] = {8},
    [975] = {6},
    [976] = {7},
    [977] = {9},
    [978] = {8},
    [979] = {6},
    [980] = {6},
    [981] = {8},
    [982] = {5},
    [983] = {6},
    [984] = {9},
    [985] = {7},
    [986] = {4},
    [987] = {9},
    [988] = {8},
    [989] = {9},
    [990] = {5},
    [991] = {8},
    [992] = {6},
    [993] = {5},
    [994] = {8},
    [995] = {9},
    [996] = {6},
    [997] = {7},
    [998] = {9},
    [999] = {6},
    [1000] = {8},
    [1001] = {8},
    [1002] = {9},
    [1003] = {9},
    [1004] = {9},
    [1005] = {9},
    [1006] = {6},
    [1007] = {4},
    [1008] = {6},
    [1009] = {7},
    [1010] = {8},
    [1011] = {7},
    [1012] = {5},
    [1013] = {3, 6, 9},
    [1014] = false,
    [1015] = false,
    [1016] = false,
    [1017] = false,
    [1018] = false,
    [1019] = false,
    [1020] = false,
    [1021] = false,
    [1022] = false,
    [1023] = false,
    [1024] = false,
    [1025] = false,
    [1026] = false,
    [1027] = false,
    [1028] = false,
    [1029] = false,
    [1030] = false,
    [1031] = false,
    [1032] = false,
    [1033] = false,
    [1034] = false,
    [1035] = false,
    [1036] = false,
    [1037] = false,
    [1038] = false,
    [1039] = {6},
    [1040] = {6},
    [1041] = false,
    [1042] = {8},
    [1043] = false,
    [1044] = false,
    [1045] = false,
    [1046] = false,
    [1047] = false,
    [1048] = false,
    [1049] = false,
    [1050] = false,
    [1051] = false,
    [1052] = false,
    [1053] = false,
    [1054] = false,
    [1055] = false,
    [1056] = false,
    [1057] = false,
    [1058] = false,
    [1059] = false,
    [1060] = false,
    [1061] = {5},
    [1062] = {3, 9, 10, 12},
    [1063] = {8},
    [1064] = false,
    [1065] = {8},
    [1066] = {10},
    [1067] = {7},
    [1068] = {3, 5, 8, 10},
    [1069] = false,
    [1070] = false,
    [1071] = false,
    [1072] = false,
    [1073] = {12},
    [1074] = false,
    [1075] = false,
    [1076] = false,
    [1077] = false,
    [1078] = false,
    [1079] = false,
    [1080] = false,
    [1081] = false,
    [1082] = false,
    [1083] = false,
    [1084] = false,
    [1085] = false,
    [1086] = false,
    [1087] = false,
    [1088] = false,
    [1089] = false,
    [1090] = false,
    [1091] = false,
    [1092] = false,
    [1093] = false,
    [1094] = false,
    [1095] = false,
    [1096] = false,
    [1097] = false,
    [1098] = false,
    [1099] = false,
    [1100] = false,
    [1101] = false,
    [1102] = false,
    [1103] = false,
    [1104] = false,
    [1105] = false,
    [1106] = false,
    [1107] = false,
    [1108] = false,
    [1109] = false,
    [1110] = false,
    [1111] = false,
    [1112] = false,
    [1113] = false,
    [1114] = false,
    [1115] = false,
    [1116] = false,
    [1117] = {3},
    [1118] = false,
    [1119] = false,
    [1120] = false,
    [1121] = false,
    [1122] = false,
    [1123] = false,
    [1124] = {8},
    [1125] = {3},
    [1126] = {7},
    [1127] = {8},
    [1128] = {3, 12},
    [1129] = {7},
    [1130] = {8},
    [1131] = {11},
    [1132] = {5},
    [1133] = {10},
    [1134] = {9},
    [1135] = {12},
    [1136] = {3},
    [1137] = {6},
    [1138] = {9},
    [1139] = {8},
    [1140] = {3},
    [1141] = {7},
    [1142] = {11},
    [1143] = {8},
    [1144] = {9},
    [1145] = {5},
    [1146] = {7},
    [1147] = {4},
    [1148] = false,
    [1149] = {8},
    [1150] = {9},
    [1151] = {7},
    [1152] = {6},
    [1153] = {4},
    [1154] = {9},
    [1155] = {6},
    [1156] = {8},
    [1157] = {3, 12},
    [1158] = {12},
    [1159] = {12},
    [1160] = {8},
    [1161] = {4, 8, 10},
    [1162] = {5, 8},
    [1163] = {6, 7},
    [1164] = {3, 5, 11},
    [1165] = {4, 8, 10},
    [1166] = {4, 8, 10},
    [1167] = {4, 8, 10},
    [1168] = {12},
    [1169] = false,
    [1170] = false,
    [1171] = false,
    [1172] = false,
    [1173] = false,
    [1174] = {12},
    [1175] = {3, 12},
    [1176] = {3},
    [1177] = {6, 7, 9, 10},
    [1178] = {4},
    [1179] = {3},
    [1180] = {4, 5, 8, 10},
    [1181] = {6, 9},
    [1182] = {3, 12},
    [1183] = {4},
    [1184] = {4},
    [1185] = {9},
    [1186] = false,
    [1187] = {4},
    [1188] = {3},
    [1189] = {9},
    [1190] = {11},
    [1191] = {6},
    [1192] = {10},
    [1193] = {12},
    [1194] = {8},
    [1195] = {5},
    [1196] = {9},
    [1197] = {7},
    [1198] = {8},
    [1199] = false,
    [1200] = {8},
    [1201] = {10},
    [1202] = {3, 10},
    [1203] = false,
    [1204] = {11},
    [1205] = {3, 6, 7, 9, 10},
    [1206] = {10},
    [1207] = {12},
    [1208] = {11},
    [1209] = {3},
    [1210] = false,
    [1211] = {4, 5, 8, 10},
    [1212] = {4, 5, 8, 10},
    [1213] = {4, 5, 8, 10},
    [1214] = false,
    [1215] = false,
    [1216] = false,
    [1217] = false,
    [1218] = false,
    [1219] = false,
    [1220] = false,
    [1221] = false,
    [1222] = false,
    [1223] = false,
    [1224] = false,
    [1225] = false,
    [1226] = {3, 4, 5, 8, 10},
    [1227] = {6, 7, 9},
    [1228] = {4, 6, 8},
    [1229] = {5, 8, 10},
    [1230] = {6, 7, 9},
    [1231] = {3, 10, 11, 12},
    [1232] = {3, 10, 12},
    [1233] = {4, 6, 7, 8},
    [1234] = {3, 6, 7, 9},
    [1235] = {5, 11, 12},
    [1236] = {8},
    [1237] = {8},
    [1238] = {3, 6},
    [1239] = false,
    [1240] = false,
    [1241] = false,
    [1242] = false,
    [1243] = {8},
    [1244] = {7},
    [1245] = {3, 6, 9},
    [1246] = false,
    [1247] = {8},
    [1248] = {3},
    [1249] = false,
    [1250] = false,
    [1251] = false,
    [1252] = false,
    [1253] = false,
    [1254] = false,
    [1255] = {8}, -- UNUSED: Murkimus Tyrannicus
    [1256] = {10, 11}, -- NEW: Rascal-Bot
    [1257] = {3}, -- HIDDEN: Crafty
    [1258] = {8}, -- HIDDEN: Angara
    [1259] = {6}, -- HIDDEN: Widowling
    [1260] = false,
    [1261] = false,
    [1262] = false,
    [1263] = false,
    [1264] = false,
    [1265] = false,
    [1266] = {4},
    [1267] = {8},
    [1268] = {6},
    [1269] = {4},
    [1270] = false,
    [1271] = {5},
    [1272] = false,
    [1273] = false,
    [1274] = false,
    [1275] = false,
    [1276] = {4, 5, 8},
    [1277] = {5},
    [1278] = {4},
    [1279] = {6},
    [1280] = {6},
    [1281] = {5},
    [1282] = {8},
    [1283] = {4},
    [1284] = {6},
    [1285] = {5},
    [1286] = {5},
    [1287] = {4},
    [1288] = {6},
    [1289] = {4},
    [1290] = {3},
    [1291] = {3},
    [1292] = {7},
    [1293] = {5},
    [1294] = false,
    [1295] = {8},
    [1296] = {6},
    [1297] = {5},
    [1298] = {4},
    [1299] = {5},
    [1300] = {4},
    [1301] = {6},
    [1302] = false,
    [1303] = {8},
    [1304] = {8},
    [1305] = {8},
    [1306] = false,
    [1307] = false,
    [1308] = false,
    [1309] = false,
    [1310] = false,
    [1311] = {8},
    [1312] = false,
    [1313] = false,
    [1314] = false,
    [1315] = false,
    [1316] = false,
    [1317] = {8},
    [1318] = false,
    [1319] = {6},
    [1320] = {5},
    [1321] = {4, 5, 7, 8, 10},
    [1322] = {4, 6, 7},
    [1323] = {3, 4, 5, 10, 11},
    [1324] = {3, 8, 9, 11},
    [1325] = {3, 8, 9},
    [1326] = {3, 8, 9},
    [1327] = false,
    [1328] = {3, 6, 7, 9, 12},
    [1329] = {5, 8, 9, 11},
    [1330] = {3, 4, 5, 6, 8},
    [1331] = {4, 8, 10},
    [1332] = {4, 5, 6},
    [1333] = {3, 5, 8, 9},
    [1334] = {6, 7, 9},
    [1335] = {8},
    [1336] = {3, 6, 7, 9, 12},
    [1337] = {4, 6},
    [1338] = {3, 7, 12},
    [1339] = {3},
    [1340] = false,
    [1341] = false,
    [1342] = false,
    [1343] = {4, 5, 7, 8, 9},
    [1344] = {7},
    [1345] = {6, 9},
    [1346] = {9},
    [1347] = false,
    [1348] = {8},
    [1349] = {3}, -- NEW: Rotten Little Helper
    [1350] = {3}, -- NEW: Sky Lantern
    [1351] = {7}, -- NEW: Macabre Marionette
    [1352] = {6}, -- HIDDEN: Chubbs
    [1353] = false,
    [1354] = {3}, -- HIDDEN: C92 Annihilator
}

--[[
local a,b = 0,0
for k,v in pairs(lib.breedData.speciesToAvailableBreeds) do a = a+1 end
for k,v in pairs(lib.breedData.speciesToBaseStatProfile) do b = b+1 end

missingPets = ""
for k,v in pairs(lib.breedData.speciesToBaseStatProfile) do 
	if not lib.breedData.speciesToAvailableBreeds[k] then
		missingPets = missingPets..k..", "
		print(k)
	end
end


print(a,b)]]